@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2021 openpyxl
+# Copyright (c) 2010-2022 openpyxl
 
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
@@ -671,7 +671,7 @@ class RangePr(Serialisable):
     def __init__(self,
                  autoStart=True,
                  autoEnd=True,
-                 groupBy=range,
+                 groupBy="range",
                  startNum=None,
                  endNum=None,
                  startDate=None,
